/*---------------------------------------------------------------------------

          Copyright 1992 David Birley - All Rights Reserved

=============================================================================

   Module:        INDIV.C

   Author:        David Birley

   Description:   Opens INDIV2.DAT file and extracts data

   Called by:     MAIN_MEN.c

   Problems:      None known.

   History:

     Version    Date    By                 Reason/Description
     -------  --------  ---  ------------------------------------------------
       1.0    08/12/92  DHB  New Version

   Comment:       This file contains the structures for accessing the data
                  in INDIV2.DAT of PAF.  The GLOBAL.H file included contains
                  no data structures.  Because of the nature of the task
                  performed by AUTOID it was not necessary to access either
                  MARR2.DAT or NOTES2.DAT, but the form of this file may
                  help as a guide to building the structs for them.

 ---------------------------------------------------------------------------*/

#include "global.h"
#define REC_SIZE 92
char ananan_num[8];

int indiv(opt)
int opt;
{
   FILE *fp;
   register int i,j;
   int qty_recs;
   int rv;
   WINDOWPTR w3;
   struct {
      char spc1[1];
      char rec_nums[10];
      char first_del[10];
      char spc2[71];
   } header;
   struct {
     char surname[2];
     char givnm1[2];
     char givnm2[2];
     char givnm3[2];
     char title[2];
     char sex[1];
     char birdate[4];
     char birplace1[2];
     char birplace2[2];
     char birplace3[2];
     char birplace4[2];
     char cdate[4];
     char cplace1[2];
     char cplace2[2];
     char cplace3[2];
     char cplace4[2];
     char ddate[4];
     char dplace1[2];
     char dplace2[2];
     char dplace3[2];
     char dplace4[2];
     char burdate[4];
     char burplace1[2];
     char burplace2[2];
     char burplace3[2];
     char burplace4[2];
     char bapdate[3];
     char baptpl[2];
     char enddate[3];
     char endtpl[2];
     char spdate[3];
     char sptpl[2];
     char older_sib[2];
     char own_mrgptr[2];
     char par_mrgptr[2];
     char id[10];
     char note_pad[2];
   } indiv;
   char scratch_str[80];
   char ana_scratch[6];
   int ls,sb;
   return_code = 1;
   if (opt != 3)
   {
      rv = ananan();
      if (rv < 0)
      {
         return_code = rv;
         goto common_exit_point;
      }
   }
   if ((fp = fopen("indiv2.dat", "r+b"))==NULL)
   {
      strcpy(scratch_str,"Cannot open file INDIV2.DAT");
      ls = strlen(scratch_str);
      sb = ((78 - ls) / 2) - 2; 
      w3 = wn_open(510,16,sb,ls + 4,3,pop2w,pop2b);
      wn_puts(w3,1,2,scratch_str);
      paktc();
      wn_close(w3);
      return_code = -1;
      goto common_exit_point;
   }
   if(fread(&header,REC_SIZE,1,fp)==0)
   {
      return_code = -2;
      goto common_exit_point;
   }
   qty_recs = atoi(header.rec_nums);
   i = 1;
   sprintf(scratch_str,
      "Writing ID: %10s to record number: %5d",ananan_num,i);
   ls = strlen(scratch_str)+2;
   sb = ((78 - ls) / 2) - 2;
   w3 = wn_open(510,9,sb,ls + 4,3,pop2w,pop2b);
   while (! feof(fp) && i <= qty_recs)
   {
      fread(&indiv,REC_SIZE,1,fp);
      if (opt ==3)
      {
         sprintf(scratch_str,
            "    Removing ID from record number: %5d",i++);
         fillch(indiv.id,NULL,10);
         goto put_write;
      }
      if (strcmp(indiv.sex,"D") != 0)
      {
         if (strlen(indiv.id)==0)
         {
            anabump();
            sprintf(scratch_str,
               "Writing ID: %10s to record number: %5d",ananan_num,i++);
            strcpy(indiv.id,ananan_num);
         }
         else
         {
            if (opt == 1)
            {
               anabump();
               sprintf(scratch_str,
                  "Writing ID: %10s to record number: %5d",ananan_num,i++);
               strcpy(indiv.id,ananan_num);
            }
            else
               sprintf(scratch_str,
                  "Writing ID: %10s to record number: %5d",indiv.id,i++);
         }
      }
      else i++;
put_write:
      wn_puts(w3,1,3,scratch_str);
      fseek(fp,-REC_SIZE,SEEK_CUR);
      fwrite(&indiv,REC_SIZE,1,fp);
      fseek(fp,0l,SEEK_CUR);
      if (chkesc())
      {
         return_code = 0;
         goto done;
      }
   }
done:
   if (opt != 3)
   {
      anabump();
      strcat(ananan_num,"\n");
      save_top();
   }
   wn_close(w3);
   fclose(fp);
   if ((i-1) < qty_recs)
   {
      /* error procedure: not all records were processed */
   }
common_exit_point:
   return (return_code);
}


